@@ -9,10 +9,8 @@ from torch.autograd import Function
 
 try:
     from flash_cosine_sim_attention_cuda import (
-        forward_value_64,
-        forward_value_32,
-        backward_value_64,
-        backward_value_32
+        forward,
+        backward
     )
 except ImportError:
     print('CUDA extension for flash-cosine-sim-attention was not compiled correctly - please run `pip install flash-cosine-sim-attention --force-reinstall --no-cache-dir`')
@@ -87,7 +85,7 @@ class FlashCosineSimAttention(Function):
         scale,
         causal
     ):
-        v_dim = v.shape[-1]
+        qk_dim, v_dim = q.shape[-1], v.shape[-1]
 
         batch, heads, seq, _, dim, device, dtype = *q.shape, v.shape[-1], q.device, q.dtype
 
@@ -97,15 +95,6 @@ class FlashCosineSimAttention(Function):
 
         should_backwards = any([*map(lambda t: t.requires_grad, (q, k, v, attn_bias))])
 
-        if v_dim == 64:
-            forward = forward_value_64
-            backward = backward_value_64
-        elif v_dim == 32:
-            forward = forward_value_32
-            backward = backward_value_32
-        else:
-            raise ValueError('invalid value dimension')
-
         o, l = forward(
             q, k, v,
             mask,
@@ -124,8 +113,7 @@ class FlashCosineSimAttention(Function):
 
         ctx.params = (
             scale,
-            causal,
-            backward
+            causal
         )
 
         return o
@@ -140,8 +128,7 @@ class FlashCosineSimAttention(Function):
 
         (
             scale,
-            causal,
-            backward
+            causal
         ) = ctx.params
 
         dq, dk, dv, db = backward(
